@@ -1,5 +1,5 @@
-createResample <- function(y, times = 10, list = TRUE)
-{
+createResample <- function(y, times = 10, list = TRUE) {
+  if(class(y)[1] == "Surv") y <- y[,"time"]
   trainIndex <- matrix(0, ncol = times, nrow = length(y))   
   out <- apply(trainIndex, 2, 
                function(data)
